@@ -1,11 +1,10 @@
 export ROOT_DIR="$PWD"
 
-#wget "https://github.com/RWTHmediTEC/Carna/archive/refs/tags/3.0.2.tar.gz" -O carna.tgz
-wget "http://localhost/3.0.2-p1.tar.gz" -O carna.tgz
+wget "https://github.com/kostrykin/Carna/archive/refs/tags/3.1.0.tar.gz" -O carna.tgz
 tar -vzxf carna.tgz
-cd "Carna-3.0.2"
+cd "Carna-3.1.0"
 mkdir -p build/make_release
-cd "$ROOT_DIR/Carna-3.0.2/build/make_release"
+cd "$ROOT_DIR/Carna-3.1.0/build/make_release"
 cmake -DCMAKE_BUILD_TYPE=Release -DBUILD_DOC=OFF -DBUILD_TEST=ON -DBUILD_DEMO=OFF -DCMAKE_INSTALL_PREFIX=$PREFIX -DCMAKE_PREFIX_PATH=$PREFIX -DBUILD_EGL=ON ../..
 make VERBOSE=1
 make install
